var OTABO_GW_URL = null;
var OTABO_IMG_DIR = null;
var OTABO_LANG = null;

var OTABO_BOOKING_URL = null;
var OTABO_BOOKING_COVERAGES_URL = null;
var OTABO_BOOKING_OPTIONALS_URL = null;
var OTABO_CONFIRM_URL = null;
var OTABO_FORM_URL = null;
var OTABO_RESULTS_URL = null;

var OTABO_TERMS_URL = null;

function otaboFormatCurrency(value, forServer)
{
	if (value != null && ('' + value).length > 0)
	{
		value = Math.round(('' + value).replace(',', '.') * 100);
		var euros = value >= 0 ? Math.floor(value / 100) : Math.ceil(value / 100);
		var cents = '' + Math.abs(value % 100);
		while (cents.length < 2)
		{
			cents = '0' + cents;
		}

		value = (value < 0 ? (forServer ? '-' : '- ') : '') + (forServer ? '' : '€ ')
				+ Math.abs(euros) + (forServer ? '.' : ',') + cents;
	}
	else
	{
		value = '';
	}

	return value;
}

function otaboFormatDate(value, forServer, type)
{
	if (value != null && Object.prototype.toString.call(value) != '[object Date]')
	{
		if (forServer)
		{
			value = value.substring(6, 10) + '-' + value.substring(3, 5) + '-' + value.substring(0, 2) + value.substring(10);
			if (value.length == 10)
			{
				value += ' 00:00:00';
			}

			var date = new Date(value.replace(' ', 'T'));
			var offset = date.getTimezoneOffset() / -60.0;
			var hours = Math.floor(offset);
			var minutes = (offset - hours) * 60;

			value += (hours < 0 ? '-' : '+') + (Math.abs(hours) < 10 ? '0' : '') + Math.abs(hours) + ':'
					+ (minutes < 10 ? '0' : '') + minutes;
		}
		else
		{
			value += '+00:00';
		}
	}

	var date = value == null || Object.prototype.toString.call(value) == '[object Date]' ? value : new Date(value.replace(' ', 'T'));
	if (date != null && date != undefined && Object.prototype.toString.call(date) == '[object Date]'
			&& !isNaN(date.getTime()))
	{
		var year = forServer ? date.getUTCFullYear() : date.getFullYear();
		var month = forServer ? date.getUTCMonth() + 1 : date.getMonth() + 1;
		var day = forServer ? date.getUTCDate() : date.getDate();
		var hours = forServer ? date.getUTCHours() : date.getHours();
		var min = forServer ? date.getUTCMinutes() : date.getMinutes();
		var sec = forServer ? date.getUTCSeconds() : date.getSeconds();

		month = (month < 10 ? '0' : '') + month;
		day = (day < 10 ? '0' : '') + day;
		hours = (hours < 10 ? '0' : '') + hours;
		min = (min < 10 ? '0' : '') + min;
		sec = (sec < 10 ? '0' : '') + sec;

		if (forServer)
		{
			value = year + '-' + month + '-' + day + ' ' + hours + ':' + min + ':' + sec;
		}
		else
		{
			value = type == undefined || type == 'date' || type == 'datetime' ? day + '-' + month + '-' + year : '';
			value += (type == undefined || type == 'time' || type == 'datetime') ? (value == '' ? '' : ' ') + hours + ':' + min : '';
		}
	}
	else
	{
		value = '';
	}
	
	return value;
}

function otaboRequest(postParams, callback, progressCallback, method)
{
	var url = OTABO_GW_URL;

	var xmlhttp = null;
	if (window.XMLHttpRequest)
	{
		xmlhttp = new XMLHttpRequest();
	}
	else
	{
		xmlhttp = new ActiveXObject('Microsoft.XMLHTTP');
	}

	// Callback function.
	if (progressCallback)
	{
		xmlhttp.onprogress = progressCallback;

		if (xmlhttp.upload)
		{
			xmlhttp.upload.onprogress = progressCallback;
			xmlhttp.upload.addEventListener('progress', progressCallback);
		}
	}

	xmlhttp.onreadystatechange = function()
	{
		if (xmlhttp.readyState == 4)
		{
			if (xmlhttp.status == 200)
			{
				var json = null;

				try
				{
					json = JSON.parse(xmlhttp.responseText);
				}
				catch (e)
				{
					json = null;
					callback(false, xmlhttp.responseText);
				}

				if (json != null)
				{
					callback(json && json.success, json, xmlhttp);
				}
			}
			else
			{
				var json = null;
				try
				{
					json = JSON.parse(xmlhttp.responseText);
				}
				catch (e)
				{
					json = null;
					callback(false, xmlhttp.responseText);
				}
				
				callback(false, json ? json : xmlhttp.responseText, xmlhttp);
			}
		}
	};

	// Get the parameters.
	var getp = '?action=oaj&otabo_lang=' + OTABO_LANG;
	var postp = '';
	for (var i = 0; i < postParams.length - 1; i++)
	{
		if (postParams[i + 1] != null)
		{
			var key = encodeURIComponent(postParams[i++]);
			var val = encodeURIComponent(postParams[i]);

			postp += (postp == '' ? '' : '&') + key + '=' + val;
		}
		else
		{
			i++;
		}
	}

	// Some last parameter left over? This can be a parameter string.
	if (postParams.length % 2 == 1)
	{
		postp += (postp === '' ? '' : '&') + postParams[postParams.length - 1];
	}

	xmlhttp.open(method ? method : 'POST', url + getp, true);
	if (postParams)
	{
		xmlhttp.setRequestHeader('Content-type', 'application/x-www-form-urlencoded');
	}

	xmlhttp.send(postp);
}

function otaboSleep(ms)
{
	return new Promise(resolve => setTimeout(resolve, ms));
}

function otaboLoadBookingCoverages(quote)
{
	var div = document.getElementById('otabo_coverages');
	var ul = document.createElement('ul');
	div.appendChild(ul);
	
	for (var i in quote.coverages)
	{
		var coverage = quote.coverages[i];
		var li = document.createElement('li');
		ul.appendChild(li);

		var h1 = document.createElement('h1');
		h1.innerHTML = coverage.name;
		li.appendChild(h1);
		
		var table = document.createElement('table');
		li.appendChild(table);
		
		var tr = document.createElement('tr');
		table.appendChild(tr);
		
		var td = document.createElement('td');
		td.innerHTML = _S.booking_coverage_deposit;
		tr.appendChild(td);
		
		var td = document.createElement('td');
		td.innerHTML = otaboFormatCurrency(coverage.deposit ? coverage.deposit : 0);
		tr.appendChild(td);

		if (coverage.excess_info && coverage.excess_info.length > 0)
		{
			var tr = document.createElement('tr');
			table.appendChild(tr);

			var td = document.createElement('td');
			td.innerHTML = _S.booking_coverage_excess;
			tr.appendChild(td);
			
			var td = document.createElement('td');
			td.innerHTML = coverage.excess_info.replace('\n', '<br />');
			tr.appendChild(td);

			var href = null;
			if (quote.vendor && quote.vendor.terms_url)
			{
				href = quote.vendor.terms_url;
			}
			else if (OTABO_TERMS_URL)
			{
				href = OTABO_TERMS_URL;
			}
			
			if (href)
			{
				var a = document.createElement('a');
				a.className = 'hint';
				a.target = '_blank';
				a.href = href;
				a.innerHTML = _S.booking_coverage_view_terms;
				td.appendChild(a);
			}
		}
		else if (coverage.excess_damage || coverage.excess_theft)
		{
			if (coverage.excess_damage)
			{		
				var tr = document.createElement('tr');
				table.appendChild(tr);

				var td = document.createElement('td');
				td.innerHTML = _S.booking_coverage_excess_damage;
				tr.appendChild(td);

				var td = document.createElement('td');
				td.innerHTML = otaboFormatCurrency(coverage.excess_damage);
				tr.appendChild(td);
			}
			
			if (coverage.excess_theft)
			{		
				var tr = document.createElement('tr');
				table.appendChild(tr);

				var td = document.createElement('td');
				td.innerHTML = _S.booking_coverage_excess_theft;
				tr.appendChild(td);

				var td = document.createElement('td');
				td.innerHTML = otaboFormatCurrency(coverage.excess_theft);
				tr.appendChild(td);
			}
		}
		else
		{
			var tr = document.createElement('tr');
			table.appendChild(tr);

			var td = document.createElement('td');
			td.innerHTML = _S.booking_coverage_excess;
			tr.appendChild(td);

			var td = document.createElement('td');
			td.innerHTML = otaboFormatCurrency(coverage.excess ? coverage.excess : 0);
			tr.appendChild(td);
		}

		var div = document.createElement('div');
		div.className = 'rate';
		li.appendChild(div);

		var span = document.createElement('span');
		span.innerHTML = coverage.rate > 0 ? _S.results_rate : '';
		div.appendChild(span);

		var span = document.createElement('span');
		span.innerHTML = coverage.rate > 0 ? otaboFormatCurrency(coverage.rate) : _S.results_rate_included;
		div.appendChild(span);
	
		var a = document.createElement('a');
		if (quote.optionals && quote.optionals.length > 0)
		{
			a.href = OTABO_BOOKING_OPTIONALS_URL;
		}
		else
		{
			a.href = OTABO_BOOKING_URL;
		}
		
		a.href += '&qid=' + quote.id + '&cid=' + i;
	
		var button = document.createElement('button');
		button.innerHTML = _S.results_select;
		a.appendChild(button);
	
		div.appendChild(a);
	}
}

function otaboLoadBookingDetails(osd, quote, cid, oid, countries)
{
	var details = { };
	
// 	details.name = 'Tester';
// 	details.surname = 'My Appy';
// 	details.email = 'tester@myappy.net';
// 	details.email_confirm = 'tester@myappy.net';
// 	details.phone = '+3912345345';
// 	details.address = 'Via Roma 1';
// 	details.city = 'Palermo';
// 	details.zip_code = '90141';
// 	details.country = 'IT';

	var form = document.getElementById('otabo_booking_form');
	var inputs = form.getElementsByTagName('input');
	for (var i = 0; i < inputs.length; i++)
	{
		if (inputs[i].type != 'text' || inputs[i].id == 'otabo_country')
		{
			continue;
		}
		
		inputs[i].onfocus = function()
		{
			this.classList.remove('error');
		}
		
		if (details[inputs[i].id.substring(6)])
		{
			inputs[i].value = details[inputs[i].id.substring(6)];
		}
	}
		
	var countryClick = false;
	
	var countryInput = document.getElementById('otabo_country');
	var countryList = document.getElementById('otabo_country_list');
	for (var i = 0; i < countries.length; i++)
	{
		var li = document.createElement('li');
		countryList.appendChild(li);
		li.innerHTML = countries[i].name;
		li.code = function(country)
		{
			return function()
			{
				return country.code;
			}
			
		}(countries[i]);
		
		li.onmousedown = function(country)
		{
			return function()
			{
				countryClick = true;
				details.country = country.code;

				countryInput.classList.remove('error');
				countryInput.value = country.name;
			}
		}(countries[i]);

		if (details.country && countries[i].code == details.country)
		{
			countryInput.value = li.innerHTML;
		}
	}
	
	countryInput.onfocus = function()
	{
		countryInput.parentNode.classList.remove('error');
		countryList.style.display = 'block';
	}

	countryInput.onblur = function()
	{
		var selected = false;
		for (var i = 0; i < countryList.children.length; i++)
		{
			if (!countryClick && window.getComputedStyle(countryList.children[i], null).display != 'none')
			{
				selected = true;
				countryInput.value = countryList.children[i].innerHTML;
				countryList.children[i].onmousedown();		
			
				break;					
			}
		}
		
		if (!selected && details.country)
		{
			for (var i = 0; i < countryList.children.length; i++)
			{
				if (countryList.children[i].code() == details.country)
				{
					selected = true;
					countryInput.value = countryList.children[i].innerHTML;
					countryList.children[i].onmousedown();		
			
					break;					
				}
			}

		}
		
		if (!selected)
		{
			countryInput.classList.add('error');
		}

		countryClick = false;
		countryList.style.display = 'none';
	}

	countryInput.onkeyup = function(e)
	{
		var pattern = new RegExp('.*' + countryInput.value + '.*', 'i');
		for (var i = 0; i < countryList.children.length; i++)
		{
			var li = countryList.children[i];
			li.style.display = li.innerHTML && pattern.test(li.innerHTML) ? 'block' : 'none';
		}
	}
	
	countryInput.onkeydown = function(e)
	{
		var res = true;
		if (e.keyCode == 9)
		{
			countryInput.blur();			
			res = false;
		}
		
		return res;
	}
	
	var terms = document.getElementById('otabo_terms');
	var privacy = document.getElementById('otabo_privacy');
	
	terms.onchange = function()
	{
		this.classList.remove('error');
	}
	
	privacy.onchange = function()
	{
		this.classList.remove('error');
	}
	
	document.getElementById('otabo_submit').onclick = function()
	{
		var error = false;
		var inputs = form.getElementsByTagName('input');
		for (var i = 0; i < inputs.length; i++)
		{
			if (inputs[i].type != 'text' || inputs[i].id == 'otabo_country')
			{
				continue;
			}
			
			var key = inputs[i].name.substring(6);
			details[key] = inputs[i].value;
			if (inputs[i].value == '')
			{
				inputs[i].classList.add('error');

				document.getElementById('otabo_error_msg').innerHTML = _S.booking_error_fill_form;
				error = true;
			}
		}
		
		if (!details.country || details.country == '')
		{
			document.getElementById('otabo_country').classList.add('error');

			document.getElementById('otabo_error_msg').innerHTML = _S.booking_error_fill_form;
			error = true;
		}
		
		var email = document.getElementById('otabo_email');
		var emailConf = document.getElementById('otabo_email_confirm');
		
		const re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
		if (!error && !re.test(email.value.toLowerCase()))
		{
			email.classList.add('error');
			
			error = true;
			document.getElementById('otabo_error_msg').innerHTML = _S.booking_error_email_not_valid;
		}
		else if (email.value != emailConf.value)
		{
			email.classList.add('error');
			emailConf.classList.add('error');

			error = true;
			document.getElementById('otabo_error_msg').innerHTML = _S.booking_error_emails_not_equal;
		}
		
		if (!error && (!terms.checked || !privacy.checked))
		{
			if (!terms.checked)
			{
				terms.classList.add('error');
			}
			
			if (!privacy.checked)
			{
				privacy.classList.add('error');
			}
			
			error = true;
			document.getElementById('otabo_error_msg').innerHTML = _S.booking_error_terms;
		}
		
		if (error)
		{
			document.getElementById('otabo_error').style.display = 'block';
		}
		else
		{
			document.getElementById('otabo_error').style.display = 'none';
			document.getElementById('otabo_submit').style.display = 'none';
			document.getElementById('otabo_loading').style.display = 'block';
			
			var thisQuote = JSON.parse(JSON.stringify(quote));
			thisQuote.client = details;
			
			if (cid)
			{
				thisQuote.coverage = thisQuote.coverages[cid];
			}
			
			delete thisQuote.coverages;
			
			if (oid && oid != '')
			{
				var optionals = [];
				
				var oids = oid.split(',');
				for (var i in oids)
				{
					optionals.push(thisQuote.optionals[oids[i]]);
				}
				
				thisQuote.optionals = optionals;
			}
			else
			{
				delete thisQuote.optionals;
			}
						
			otaboRequest(['cmd', 'submit', 'osd', osd, 'quote', JSON.stringify(thisQuote)], function(success, response)
			{
				document.getElementById('otabo_loading').style.display = 'none';
				if (success && response)
				{
					window.location = OTABO_CONFIRM_URL;
				}
				else
				{
					document.getElementById('otabo_submit').style.display = 'block';
					document.getElementById('otabo_error_msg').innerHTML = response && response.error ? response.error : response;
					document.getElementById('otabo_error').style.display = 'block';				
				}
			});
		}
	};
}

function otaboLoadBookingOptionals(quote, cid, groups, oid)
{
	var div = document.getElementById('otabo_optionals');

	var oidStr = '';
	var oids = oid != null && oid != '' ? oid.split(',') : [];
	
	var uls = [];
	for (var i in groups)
	{
		uls[i] = document.createElement('ul');
	}
	
	var nextLink = document.createElement('a');	
	for (var i in quote.optionals)
	{
		var optional = quote.optionals[i];
		if (!optional || !optional.id)
		{
			continue;
		}
		
		var li = document.createElement('li');

		var h1 = document.createElement('h1');
		h1.innerHTML = optional.name;
		li.appendChild(h1);
				
		var table = document.createElement('table');
		li.appendChild(table);
		
		var tr = document.createElement('tr');
		table.appendChild(tr);
		
		var td = document.createElement('td');
		td.innerHTML = _S['booking_optionals_' + optional.id] ? _S['booking_optionals_' + optional.id] : '';
		tr.appendChild(td);
		
		var td = document.createElement('td');
		td.className = 'rate';
		tr.appendChild(td);

		var span = document.createElement('span');
		span.innerHTML = optional.rate > 0 ? _S.results_rate : '';
		td.appendChild(span);

		var span = document.createElement('span');
		span.innerHTML = optional.rate > 0 ? otaboFormatCurrency(optional.rate) : _S.results_rate_included;
		td.appendChild(span);
	
		var button = document.createElement('button');
		td.appendChild(button);
		button.innerHTML = _S.results_select;
		button.onclick = function(optional, i)
		{
			return function()
			{
				if (oids.indexOf(i) == -1)
				{
					oids.push(i);
					this.innerHTML = _S.results_remove;
					this.classList.add('remove');
				}
				else
				{
					oids.splice(oids.indexOf(i), 1);
					this.innerHTML = _S.results_select;
					this.classList.remove('remove');
				}
				
				var extraTotals = 0;
				for (var ii = 0; ii < oids.length; ii++)
				{
					extraTotals += parseFloat(quote.optionals[oids[ii]].rate);
				}

				var e = document.getElementById('otabo_totals');
				if (e)
				{				
					var totals = parseFloat(quote.rate) + extraTotals;
					if (cid !== null)
					{
						totals += parseFloat(quote.coverages[cid].rate);
					}
					
					e.innerHTML = otaboFormatCurrency(totals);
					
					var list = document.getElementById('otabo_optionals_list');
					while (list.children.length > 1)
					{
						list.removeChild(list.children[1]);
					}

					oidStr = '';
					for (var ii in quote.optionals)
					{
						var optional = quote.optionals[ii];
						if (optional.id && oids.indexOf(ii) != -1)
						{
							oidStr += (oidStr == '' ? '' : ',') + ii;
							
							var span = document.createElement('span');
							list.appendChild(span);
							span.className = 'optionals';
							
							var table = document.createElement('table');
							span.appendChild(table);
							
							var tr = document.createElement('tr');
							table.appendChild(tr);
							
							var td = document.createElement('td');
							tr.appendChild(td);
							td.innerHTML = optional.name;
							
							var td = document.createElement('td');
							tr.appendChild(td);
							td.className = 'rate';
							td.innerHTML = otaboFormatCurrency(optional.rate);
						}
					}
					
					oidStr = encodeURI(oidStr);
					
					document.getElementById('otabo_coverage_modify').href = OTABO_BOOKING_COVERAGES_URL + '&oid=' + oidStr;
					document.getElementById('otabo_totals_holder').style.display = list.children.length > 1 || cid ? 'block' : 'none';
					document.getElementById('otabo_optionals_holder').style.display = list.children.length > 1 ? 'block' : 'none';
					
					document.getElementById('otabo_optionals_totals').innerHTML = otaboFormatCurrency(totals);
					nextLink.href = OTABO_BOOKING_URL + '&oid=' + oidStr;
				}
			}
		}(optional, i);
		
		if (oids.indexOf(i) == -1)
		{
			button.innerHTML = _S.results_select;
		}
		else
		{
			button.innerHTML = _S.results_remove;
			button.classList.add('remove');
		}
		
		var c = 0;
		var num = Object.keys(groups).length;
		for (var ii in groups)
		{
			if (groups[ii].indexOf(optional.id) != -1 || c == num - 1)
			{
				uls[ii].appendChild(li);
				break;
			}
			
			c++;
		}
	}
		
	for (var i in uls)
	{
		if (uls[i].children.length == 0)
		{
			continue;
		}
		
		var h1 = document.createElement('h1');
		h1.innerHTML = _S['booking_optionals_' + i];
		div.appendChild(h1);
		
		div.appendChild(uls[i]);
		var dd = document.createElement('div');
		dd.style.clear = 'both';
		div.appendChild(dd);
	}
	
	var totals = parseFloat(quote.rate);
	if (cid)
	{
		totals += parseFloat(quote.coverages[cid].rate);
	}

	var oidStr = '';
	for (var ii in quote.optionals)
	{
		var optional = quote.optionals[ii];
		if (optional.id && oids.indexOf(ii) != -1)
		{
			totals += parseFloat(optional.rate);
			oidStr += (oidStr == '' ? '' : ',') + ii;
		}
	}
	
	oidStr = encodeURI(oidStr);
	
	var thisDiv = document.createElement('div');
	div.appendChild(thisDiv);
	thisDiv.className = 'rate';
	
	var span = document.createElement('span');
	thisDiv.appendChild(span);
	span.innerHTML = _S.booking_optionals_totals;
	
	var span = document.createElement('span');
	thisDiv.appendChild(span);
	span.id = 'otabo_optionals_totals';
	span.innerHTML = otaboFormatCurrency(totals);
	
	var button = document.createElement('button');
	thisDiv.appendChild(button);
	button.innerHTML = _S.booking_optionals_next;
	
	thisDiv.appendChild(nextLink);
	nextLink.href = OTABO_BOOKING_URL + '&oid=' + oidStr;
	nextLink.appendChild(button);
}


function otaboLoadForm(osd)
{
	otaboRequest(['cmd', 'bases', 'osd', osd], function(success, response)
	{
		if (success && response)
		{
			if (!response.hasOwnProperty('checkin_time'))
			{
				response.checkout_time = new Date();
				response.checkout_time.setHours(response.checkout_time.getHours() + 1, 0, 0, 0);

				response.checkin_time = new Date();
				response.checkin_time.setDate(response.checkin_time.getDate() + 2);
				response.checkin_time.setHours(response.checkout_time.getHours(), 0, 0, 0);

				response.checkout_time = otaboFormatDate(response.checkout_time, true);
				response.checkin_time = otaboFormatDate(response.checkin_time, true);
			}
			
			var otaboInput =
			{
				checkout_base : response.checkout_base ? response.checkout_base : null,
				checkout_time : response.checkout_time,
				checkin_base : response.checkin_base ? response.checkin_base : null,
				checkin_time : response.checkin_time
			};

			var today = new Date();
			today.setHours(0, 0, 0, 0);

			// POPUPS
			var checkinBases = [];

			var checkoutBase = document.getElementById('otabo_checkout_base_list');
			var checkinBase = document.getElementById('otabo_checkin_base_list');
			var checkoutDateCalendar = document.getElementById('otabo_checkout_date_calendar');
			var checkinDateCalendar = document.getElementById('otabo_checkin_date_calendar');

			///
			///
			// CHECKOUT BASE
			///
			///
			var checkoutBaseInput = document.getElementById('otabo_checkout_base');
			var checkinBaseInput = document.getElementById('otabo_checkin_base');

			checkoutBaseInput.onfocus = function()
			{
				checkoutBaseInput.parentNode.classList.remove('error');

				checkoutBase.style.display = 'block';
				checkinBase.style.display = 'none';
				checkoutDateCalendar.style.display = 'none';
				checkinDateCalendar.style.display = 'none';
				checkinTime.style.display = 'none';
				checkinTime.style.display = 'none';
			}

			checkoutBaseInput.onblur = function()
			{
				if (!otaboInput.checkout_base || otaboInput.checkout_base.name != this.value)
				{
					var selected = false;
					for (var i = 0; i < checkoutBase.children.length; i++)
					{
						if (window.getComputedStyle(checkoutBase.children[i], null).display != 'none')
						{
							selected = true;
							checkoutBase.children[i].onmousedown();		
							
							break;					
						}
					}
					
					if (!selected)
					{
						checkoutBaseInput.parentNode.classList.add('error');
					}
				}

				checkoutBase.style.display = 'none';
			}

			checkoutBaseInput.onkeyup = function(e)
			{
				var pattern = new RegExp('.*' + checkoutBaseInput.value + '.*', 'i');
				for (var i = 0; i < checkoutBase.children.length; i++)
				{
					var li = checkoutBase.children[i];
					li.style.display = li.innerHTML && pattern.test(li.innerHTML) ? 'block' : 'none';
				}
			}
			
			checkoutBaseInput.onkeydown = function(e)
			{
				var res = true;
				if (e.keyCode == 9)
				{
					checkoutBaseInput.blur();
					if (window.getComputedStyle(checkinBaseInput.parentNode, null).display != 'none')
					{
						checkinBaseInput.focus();
					}
					else
					{
						checkoutDate.onclick();
					}
					
					res = false;
				}
				
				return res;
			}

			for (var i in response.base)
			{
				var li = document.createElement('li');
				checkoutBase.appendChild(li);
 				li.innerHTML = response.base[i].name;
 				li.onmousedown = function(base)
 				{
 					return function()
 					{
 						checkoutBase.parentNode.className = 'input';
						checkoutBaseInput.value = base.name;

						otaboInput.checkout_base = base;
						otaboInput.checkin_base = null;
						
						checkinBaseInput.value = '';
					}

 				}(response.base[i]);
 				
 				if (otaboInput.checkout_base && JSON.stringify(response.base[i].uid) == JSON.stringify(otaboInput.checkout_base.uid))
 				{
 					checkoutBaseInput.value = response.base[i].name;
 				}
 			}

			///
			///
			// CHECKIN BASE
			///
			///
			document.getElementById('otabo_checkin_base_select_tick').onclick = function()
			{
				var shown = document.getElementById('otabo_checkin_base_select').checked;
				document.getElementById('otabo_checkin_base_label').style.display = shown ? 'block' : 'none';
				document.getElementById('otabo_checkin_base').parentNode.style.display = shown ? 'block' : 'none';
			};
			
			var checkinBaseInput = document.getElementById('otabo_checkin_base');
			checkinBaseInput.onfocus = function()
			{
				while (checkinBase.children.length > 0)
				{
					checkinBase.removeChild(checkinBase.children[0]);
				}
				
				// Add all the bases for the corresponding checkout base.
				if (otaboInput.checkout_base)
				{
					for (var i = 0; i < response.base.length; i++)
					{
						for (var j = 0; j < otaboInput.checkout_base.uuid.length; j++)
						{
							if (response.base[i].uuid.indexOf(otaboInput.checkout_base.uuid[j]) != -1)
							{
								var li = document.createElement('li');
								checkinBase.appendChild(li);
								li.innerHTML = response.base[i].name;
								li.onmousedown = function(base)
								{
									return function()
									{
										checkinBase.parentNode.className = 'input';
										checkinBaseInput.value = base.name;

										otaboInput.checkin_base = base;
									}

								}(response.base[i]);

								if (otaboInput.checkin_base && response.base[i].uid == otaboInput.checkin_base.uid)
								{
									checkinBaseInput.value = response.base[i].name;
								}
								
								break;
							}
						}
					}
				}
				else
				{
					var li = document.createElement('li');
					li.innerHTML = _S.checkout_base_select;
					checkinBase.appendChild(li);
				}
			
				checkoutBase.style.display = 'none';
				checkinBase.style.display = 'block';
				checkoutDateCalendar.style.display = 'none';
				checkinDateCalendar.style.display = 'none';
				checkinTime.style.display = 'none';
				checkinTime.style.display = 'none';
			}

			checkinBaseInput.onblur = function()
			{
				if (!otaboInput.checkin_base || otaboInput.checkin_base.name != this.value)
				{
					var selected = false;
					for (var i = 0; i < checkinBase.children.length; i++)
					{
						if (window.getComputedStyle(checkinBase.children[i], null).display != 'none'
								&& checkinBase.children[i].onmousedown)
						{
							selected = true;
							checkinBase.children[i].onmousedown();							
							
							break;
						}
					}
					
					if (!selected)
					{
						checkinBaseInput.parentNode.classList.add('error');
					}
				}
				
				checkinBase.style.display = 'none';
			}

			checkinBaseInput.onkeyup = function()
			{
				var pattern = new RegExp('.*' + checkinBaseInput.value + '.*', 'i');
				for (var i = 0; i < checkinBase.children.length; i++)
				{
					var li = checkinBase.children[i];
					li.style.display = li.innerHTML && pattern.test(li.innerHTML) ? 'block' : 'none';
				}
			}
			
			checkinBaseInput.onkeydown = function(e)
			{
				var res = true;
				if (e.keyCode == 9)
				{
					checkinBaseInput.blur();
					checkoutDate.onclick();
					
					res = false;
				}
				
				return res;
			}
			
			///
			///
			// CHECKOUT DATE
			///
			///
			var checkoutDate = document.getElementById('otabo_checkout_date');
			var checkoutDateTable = document.getElementById('otabo_checkout_date_table');
			var checkoutDateTableDate = new Date();
 			checkoutDateTableDate.setDate(1);
 			checkoutDateTableDate.setHours(0, 0, 0, 0);

 			checkoutDate.innerHTML = otaboFormatDate(otaboInput.checkout_time, false, 'date');
			checkoutDate.onclick = function()
			{
				var shown = window.getComputedStyle(checkoutDateCalendar, null).display != 'none';
				if (!shown)
				{
					checkoutBaseInput.blur();
					checkinBaseInput.blur();
					checkinDateCalendar.style.display = 'none';
					checkoutTimeInput.blur();
					checkinTimeInput.blur();

					loadMonth(document.getElementById('otabo_checkout_date_title'), document.getElementById('otabo_checkout_date_left'),
							document.getElementById('otabo_checkout_date_right'), checkoutDateTable, checkoutDateTableDate);
				}

				checkoutDateCalendar.style.display = shown ? 'none' : 'block';
			};
			
			///
			///
			// CHECKOUT TIME
			///
			///
			var checkoutTime = document.getElementById('otabo_checkout_time');
			var checkoutTimeInput = document.getElementById('otabo_checkout_time_input');
			
			var time = new Date(2000, 1, 1, 0, 0, 0);
			var day = time.getDate();

			while (time.getDate() == day)
			{
				var li = document.createElement('li');
				checkoutTime.appendChild(li);
 				li.innerHTML = otaboFormatDate(time, false, 'time');
 				li.onmousedown = function()
 				{
					checkoutTime.parentNode.className = 'input';
					checkoutTimeInput.value = this.innerHTML;

					otaboInput.checkout_time = otaboFormatDate(otaboFormatDate(otaboInput.checkout_time, false, 'date') + ' ' + this.innerHTML, true);

 				};

				time.setMinutes(time.getMinutes() + 15);
			}

			checkoutTimeInput.value = otaboFormatDate(otaboInput.checkout_time, false, 'time');
			
			checkoutTimeInput.onfocus = function()
			{
				checkoutTimeInput.parentNode.classList.remove('error');

				checkoutBase.style.display = 'none';
				checkinBase.style.display = 'none';
				checkoutDateCalendar.style.display = 'none';
				checkinDateCalendar.style.display = 'none';
				checkoutTime.style.display = 'block';
				checkinTime.style.display = 'none';
			}
			
			checkoutTimeInput.onblur = function()
			{
				if (!checkoutTimeInput.value || checkoutTimeInput.value != otaboFormatDate(otaboInput.checkout_time, false, 'time'))
				{
					var selected = false;
					for (var i = 0; i < checkoutTime.children.length; i++)
					{
						if (window.getComputedStyle(checkoutTime.children[i], null).display != 'none')
						{
							selected = true;
							checkoutTime.children[i].onmousedown();	
							
							break;						
						}
					}
					
					if (!selected)
					{
						checkoutTimeInput.parentNode.classList.add('error');
					}
				}
				
				checkoutTime.style.display = 'none';
			}

			checkoutTimeInput.onkeyup = function()
			{
				var pattern = new RegExp(checkoutTimeInput.value + '.*', 'i');
				for (var i = 0; i < checkoutTime.children.length; i++)
				{
					var li = checkoutTime.children[i];
					li.style.display = li.innerHTML && pattern.test(li.innerHTML) ? 'block' : 'none';
				}
			}
			
			///
			///
			// CHECKIN DATE
			///
			///
			var checkinDate = document.getElementById('otabo_checkin_date');
			var checkinDateTable = document.getElementById('otabo_checkin_date_table');
			var checkinDateTableDate = new Date();
			checkinDateTableDate.setDate(1);
 			checkinDateTableDate.setHours(0, 0, 0, 0);

 			checkinDate.innerHTML = otaboFormatDate(otaboInput.checkin_time, false, 'date');
			checkinDate.onclick = function()
			{
				checkinDate.parentNode.classList.remove('error');
				checkinTimeInput.parentNode.classList.remove('error');

				var shown = window.getComputedStyle(checkinDateCalendar, null).display != 'none';
				if (!shown)
				{
					checkoutBaseInput.blur();
					checkinBaseInput.blur();
					checkoutDateCalendar.style.display = 'none';
					checkoutTimeInput.blur();
					checkinTimeInput.blur();

					loadMonth(document.getElementById('otabo_checkin_date_title'), document.getElementById('otabo_checkin_date_left'),
							document.getElementById('otabo_checkin_date_right'), checkinDateTable, checkinDateTableDate);
				}

				checkinDateCalendar.style.display = shown ? 'none' : 'block';
			};


			///
			///
			// CHECKIN TIME
			///
			///
			var checkinTime = document.getElementById('otabo_checkin_time');
			var checkinTimeInput = document.getElementById('otabo_checkin_time_input');
			
			var time = new Date(2000, 1, 1, 0, 0, 0);
			var day = time.getDate();

			while (time.getDate() == day)
			{
				var li = document.createElement('li');
				checkinTime.appendChild(li);
 				li.innerHTML = otaboFormatDate(time, false, 'time');
 				li.onmousedown = function()
 				{
					checkinTime.parentNode.className = 'input';
					checkinTimeInput.value = this.innerHTML;

					otaboInput.checkin_time = otaboFormatDate(otaboFormatDate(otaboInput.checkin_time, false, 'date') + ' ' + this.innerHTML, true);

 				};

				time.setMinutes(time.getMinutes() + 15);
			}

			checkinTimeInput.value = otaboFormatDate(otaboInput.checkin_time, false, 'time');
			
			checkinTimeInput.onfocus = function()
			{
				checkinDate.parentNode.classList.remove('error');
				checkinTimeInput.parentNode.classList.remove('error');

				checkoutBase.style.display = 'none';
				checkinBase.style.display = 'none';
				checkoutDateCalendar.style.display = 'none';
				checkinDateCalendar.style.display = 'none';
				checkoutTime.style.display = 'none';
				checkinTime.style.display = 'block';
			}
			
			checkinTimeInput.onblur = function()
			{
				if (!checkinTimeInput.value || checkinTimeInput.value != otaboFormatDate(otaboInput.checkin_time, false, 'time'))
				{
					var selected = false;
					for (var i = 0; i < checkinTime.children.length; i++)
					{
						if (window.getComputedStyle(checkinTime.children[i], null).display != 'none')
						{
							selected = true;
							checkinTime.children[i].onmousedown();							
							
							break;
						}
					}
					
					if (!selected)
					{
						checkinTimeInput.parentNode.classList.add('error');
					}
				}
				
				checkinTime.style.display = 'none';
			}

			checkinTimeInput.onkeyup = function()
			{
				var pattern = new RegExp(checkinTimeInput.value + '.*', 'i');
				for (var i = 0; i < checkinTime.children.length; i++)
				{
					var li = checkinTime.children[i];
					li.style.display = li.innerHTML && pattern.test(li.innerHTML) ? 'block' : 'none';
				}
			}

			///
			///
			// CALENDAR
			///
			///
			var loadMonth = function(title, left, right, table, shownDate)
			{
				title.innerHTML = _S['month_' + shownDate.getMonth()] + ' ' + shownDate.getFullYear();
				left.onclick = function()
				{
					shownDate.setMonth(shownDate.getMonth() - 1);
					loadMonth(title, left, right, table, shownDate);
				};

				right.onclick = function()
				{
					shownDate.setMonth(shownDate.getMonth() + 1);
					loadMonth(title, left, right, table, shownDate);
				};

				while (table.firstChild)
				{
					table.removeChild(table.firstChild);
				}

				var date = new Date(shownDate);
				var m = date.getMonth();
				var tr = document.createElement('tr');
				table.appendChild(tr);

				// Empty cells before first day of month.
				var day = date.getDay() == 0 ? 7 : date.getDay();
				while (tr.children.length < day - 1)
				{
					var td = document.createElement('td');
					tr.appendChild(td);
					td.className = 'none';
				}

				// Days.
				while (m == date.getMonth())
				{
					day = date.getDay() == 0 ? 7 : date.getDay();
					if (day == 1 && date.getDate() != 1)
					{
						tr = document.createElement('tr');
						table.appendChild(tr);
					}

					var td = document.createElement('td');
					tr.appendChild(td);
					td.innerHTML = date.getDate();

					if (title.id == 'otabo_checkout_date_title' && otaboInput.checkout_time == otaboFormatDate(date, true)
							|| title.id == 'otabo_checkin_date_title' && otaboInput.checkin_time == otaboFormatDate(date, true))
					{
						td.className = 'selected';
					}

					if (title.id == 'otabo_checkout_date_title' && date.getTime() >= today.getTime()
							|| title.id == 'otabo_checkin_date_title' && otaboFormatDate(date, true) >= otaboInput.checkout_time)
					{
						td.onclick = function(title, left, right, table, shownDate, date)
						{
							return function()
							{
								var string = otaboFormatDate(date, false, 'date');
								if (title.id == 'otabo_checkout_date_title')
								{
									date.setHours(otaboInput.checkout_time.substring(0, 2), otaboInput.checkout_time.substring(3, 2), 0, 0);

									otaboInput.checkout_time = otaboFormatDate(date, true);
									checkoutDateCalendar.style.display = 'none';
									document.getElementById('otabo_checkout_date').innerHTML = otaboFormatDate(date, false, 'date');

									if (otaboInput.checkin_time < otaboInput.checkout_time)
									{
										checkinDateTableDate.setFullYear(date.getFullYear(), date.getMonth(), 1);
										otaboInput.checkin_time = otaboFormatDate(otaboFormatDate(new Date(date.getFullYear(), date.getMonth(), date.getDate() + 1), false, 'date')
												+ otaboInput.checkin_time.substr(10), true);

										checkinDate.innerHTML = otaboFormatDate(otaboInput.checkin_time, false, 'date')
										loadMonth(document.getElementById('otabo_checkin_date_title'), document.getElementById('otabo_checkin_date_left'),
												document.getElementById('otabo_checkin_date_right'), checkinDateTable, checkinDateTableDate);
									}
								}
								else
								{
									date.setHours(otaboInput.checkin_time.substring(0, 2), otaboInput.checkin_time.substring(3, 2), 0, 0);

									otaboInput.checkin_time = otaboFormatDate(date, true);
									checkinDateCalendar.style.display = 'none';
									document.getElementById('otabo_checkin_date').innerHTML = otaboFormatDate(date, false, 'date');
								}
							}
						}(title, left, right, table, shownDate, new Date(date));
					}
					else
					{
						td.className = 'disabled';
					}

					date.setDate(date.getDate() + 1);
				}

				// Empty cells at the end.
				day = tr.children.length;
				for (; day < 7; day++)
				{
					var td = document.createElement('td');
					tr.appendChild(td);
					td.className = 'none';
				}
			};

			loadMonth(document.getElementById('otabo_checkin_date_title'), document.getElementById('otabo_checkin_date_left'),
					document.getElementById('otabo_checkin_date_right'), checkinDateTable, checkinDateTableDate);
					
			///
			///
			// SUBMIT BUTTON
			///
			///
			document.getElementById('otabo_check_dates').onclick = function()
			{
				var error = false;
				if (!otaboInput.checkout_base)
				{
					error = true;
					checkoutBaseInput.parentNode.classList.add('error');
				}
				
				if (document.getElementById('otabo_checkin_base_select_tick').checked && !otaboInput.checkin_base)
				{
					error = true;
					checkinBaseInput.parentNode.classList.add('error');
				}
				
				if (otaboInput.checkout_time >= otaboInput.checkin_time)
				{
					error = true;
					checkinDate.parentNode.classList.add('error');
					checkinTime.parentNode.classList.add('error');
				}
				
				if (!error)
				{
					window.location = OTABO_RESULTS_URL
							+ (OTABO_RESULTS_URL.indexOf('?osd=') == -1 ? '?osd=' + osd : '')
							+ '&ob=' + encodeURI(otaboInput.checkout_base.index)
							+ '&ib=' + encodeURI(otaboInput.checkin_base ? otaboInput.checkin_base.index : '')
							+ '&ot=' + encodeURI(otaboInput.checkout_time)
							+ '&it=' + encodeURI(otaboInput.checkin_time)
							+ '&obs=' + encodeURI(otaboInput.checkout_base.name)
							+ '&ibs=' + encodeURI(otaboInput.checkin_base ? otaboInput.checkin_base.name : '');
				}
			};
		}
		else
		{
			document.getElementById('otabo_error').style.display = 'block';
			document.getElementById('otabo_error_msg').innerHTML = response && response.error ? response.error : response;
		}
	});
}

function otaboLoadResults(osd, ob, ib, ot, it)
{
	var loading = document.getElementById('otabo_loading');
	loading.style.display = 'block';
	
	var params = ob ? ['cmd', 'results', 'osd', osd, 'ob', ob, 'ib', ib, 'ot', ot, 'it', it] : ['cmd', 'results', 'osd', osd];
	otaboRequest(params, function(success, response)
	{
		if (success && response)
		{
			if (document.getElementById('otabo_checkout_base').innerHTML == '')
			{
				document.getElementById('otabo_checkout_base').innerHTML = response.result.input.checkout_base.name;
				document.getElementById('otabo_checkin_base').innerHTML = response.result.input.checkin_base.name;
				document.getElementById('otabo_checkout_time').innerHTML = otaboFormatDate(response.result.input.checkout_time);
				document.getElementById('otabo_checkin_time').innerHTML = otaboFormatDate(response.result.input.checkin_time);
			}
			
			// Print the groups.
			var groupsDiv = document.getElementById('otabo_results_groups');
			var groupsUl = document.createElement('ul');
			groupsDiv.appendChild(groupsUl);
			
			var selectedGroups = [];
			
			for (var i in response.result.groups)
			{
				var group = response.result.groups[i];
				var li = document.createElement('li');
				li.style.backgroundImage = 'url(\'' + group.image + '\')';
				
				var span = document.createElement('span');
				span.className = 'name';
				span.innerHTML = group.name;
				li.appendChild(span);
				
				var span = document.createElement('span');
				span.className = 'rate';
				span.innerHTML = _S.results_group_rate.replace('{rate}', otaboFormatCurrency(group.min));
				li.appendChild(span);
				
				groupsUl.appendChild(li);
				
				li.onclick = function(group)
				{
					return function()
					{
						if (selectedGroups.indexOf(group.name) != -1)
						{
							selectedGroups.splice(selectedGroups.indexOf(group.name), 1);
							this.classList.remove('selected');
						}
						else
						{
							selectedGroups.push(group.name);
							this.classList.add('selected');
						}
						
						var results = [];
						for (var ii in response.result.quotes)
						{
							var quote = response.result.quotes[ii];
							if (selectedGroups.length == 0 || selectedGroups.indexOf(quote.group) != -1)
							{
								results.push(quote);
							}
						}
						
						results.sort(function(lhs, rhs)
						{
							var res = lhs.rate - rhs.rate;
							if (res == 0)
							{
								res = lhs.group.toLowerCase().localeCompare(rhs.group.toLowerCase());
							}
							
							if (res == 0)
							{
								res = lhs.name.toLowerCase().localeCompare(rhs.name.toLowerCase());
							}
						});

						printResults(results);
					}
				}(group);
			}
			
			var leftScroller = document.createElement('span');
			leftScroller.id = 'otabo_results_groups_lscroller';
			groupsDiv.appendChild(leftScroller);
			leftScroller.onclick = function()
			{
				var width = parseInt(groupsUl.children[0].offsetWidth) + parseInt(window.getComputedStyle(groupsUl.children[0]).marginRight.replace('px', ''));
				var index = Math.floor(groupsUl.scrollLeft / width);
				groupsUl.scrollLeft = groupsUl.children[Math.max(0, index - 1)].offsetLeft;
			};
			
			var rightScroller = document.createElement('span');
			rightScroller.id = 'otabo_results_groups_rscroller';
			groupsDiv.appendChild(rightScroller);
			rightScroller.onclick = function()
			{
				var width = parseInt(groupsUl.children[0].offsetWidth) + parseInt(window.getComputedStyle(groupsUl.children[0]).marginRight.replace('px', ''));
				var index = Math.floor(groupsUl.scrollLeft / width);
				groupsUl.scrollLeft = groupsUl.children[index + 1].offsetLeft;
			};
						
			groupsUl.onscroll = function()
			{
				leftScroller.style.display = groupsUl.scrollLeft > 0 ? 'block' : 'none';
				rightScroller.style.display = groupsUl.scrollLeft < groupsUl.scrollWidth - groupsUl.offsetWidth - 12 ? 'block' : 'none';
			}

			leftScroller.style.display = groupsUl.scrollLeft > 0 ? 'block' : 'none';
			rightScroller.style.display = groupsUl.scrollLeft < groupsUl.scrollWidth - groupsUl.offsetWidth - 12 ? 'block' : 'none';
			
			// Print the results table.
			var resultsDiv = document.getElementById('otabo_results');
			var resultsUl = document.createElement('ul');
			resultsDiv.appendChild(resultsUl);
			
			var printResults = function(results)
			{
				while (resultsUl.children.length > 0)
				{
					resultsUl.removeChild(resultsUl.children[0]);
				}
				
				for (var i in results)
				{
					var quote = results[i];
					var li = document.createElement('li');
					resultsUl.appendChild(li);
				
					var h1 = document.createElement('h1');
					h1.innerHTML = quote.group;
					li.appendChild(h1);

					if (quote.name && quote.name != quote.group)
					{
						var h2 = document.createElement('h2');
						h2.innerHTML = quote.name;
						li.appendChild(h2);
					}
				
					if (quote.vendor)
					{
						var ss = document.createElement('span');
						ss.className = 'company';
						ss.innerHTML = quote.vendor.name;
						ss.style.backgroundImage = 'url(\'' + quote.vendor.logo + '\')';
						li.appendChild(ss);
					}
				
					var img = document.createElement('img');
					img.src = quote.image;
					li.appendChild(img);
					
					var table = document.createElement('table');
					li.appendChild(table);
					
					var tr = document.createElement('tr');
					table.appendChild(tr);
				
					var div = document.createElement('td');
					div.className = 'params';
					tr.appendChild(div);
				
					var keys = ['seats', 'doors', 'small_bags', 'big_bags'];
					for (var k in keys)
					{
						var key = keys[k];
						if (quote.params[key])
						{
							var p1 = null;
							var p2 = null;
							var s = '';
						
							for (var i in quote.params[key])
							{
								if (quote.params[key][i])
								{
									if (p1 == null)
									{
										s += (s == '' ? '' : ', ') + i.substr(1);
										p1 = i.substr(1);
										p2 = p1;
									}
									else if (p2 == parseInt(i.substr(1)) - 1)
									{
										p2 = i.substr(1);
									}
									else
									{
										if (p2 != p1)
										{
											s += '-' + p2;
										}
									
										s += (s == '' ? '' : ', ') + i.substr(1);

										p1 = i.substr(1);
										p2 = p1;											
									}
								}
							}
						
							if (p2 != p1)
							{
								s += '-' + p2;
							}
					
							if (s != '')
							{
								var ss = document.createElement('span');
								ss.className = key;
								ss.innerHTML = s + ' ' + _S['param_' + key];
								ss.style.backgroundImage = 'url(\'' + OTABO_IMG_DIR + 'icon_param_' + key + '.png' + '\')';
								div.appendChild(ss);
							}
						}
					}
				
					if (div.children.length % 2 == 1)
					{
						var ss = document.createElement('span');
						ss.innerHTML = '&nbsp;';
						div.appendChild(ss);
					}

					if (quote.params.gearshift)
					{
						var s = '';
						for (var i in quote.params.gearshift)
						{
							s += (s == '' ? '' : ', ') + _S['param_gearshift_' + i];
						}

						if (s != '')
						{
							var ss = document.createElement('span');
							ss.className = 'gearshift';
							ss.innerHTML = s;
							ss.style.backgroundImage = 'url(\'' + OTABO_IMG_DIR + 'icon_param_gearshift.png' + '\')';
							div.appendChild(ss);
						}
					}

					if (quote.params.fuel_type)
					{
						var s = '';
						for (var i in quote.params.fuel_type)
						{
							s += (s == '' ? '' : ', ') + _S['param_fuel_type_' + i];
						}
					
						if (s != '')
						{
							var ss = document.createElement('span');
							ss.className = 'fuel_type';
							ss.innerHTML = s;
							ss.style.backgroundImage = 'url(\'' + OTABO_IMG_DIR + 'icon_param_fuel_type.png' + '\')';
							div.appendChild(ss);
						}
					}
				
					if (quote.km_limit && quote.km_limit.length > 0 && quote.km_limit_period && quote.km_limit_period.length > 0)
					{
						var ss = document.createElement('span');
						ss.className = 'km_limit';
						ss.innerHTML = quote.km_limit + ' km/' +  quote.km_limit_period;
						ss.style.backgroundImage = 'url(\'' + OTABO_IMG_DIR + 'icon_param_km_limit.png' + '\')';
						div.appendChild(ss);
					}
					else
					{
						var ss = document.createElement('span');
						ss.className = 'km_limit';
						ss.innerHTML = _S.param_km_limit_none;
						ss.style.backgroundImage = 'url(\'' + OTABO_IMG_DIR + 'icon_param_km_limit.png' + '\')';
						div.appendChild(ss);
					}
				
					if (div.children.length == 0)
					{
						div.innerHTML = '&nbsp;';
					}
				
					var div = document.createElement('td');
					div.className = 'rate';
					tr.appendChild(div);
				
					var span = document.createElement('span');
					span.innerHTML = _S.results_rate;
					div.appendChild(span);
				
					var span = document.createElement('span');
					span.innerHTML = otaboFormatCurrency(quote.rate);
					div.appendChild(span);
					
					var a = document.createElement('a');
					if (quote.coverages && quote.coverages.length > 0)
					{
						a.href = OTABO_BOOKING_COVERAGES_URL + '&qid=' + quote.id;
					}
					else if (quote.optionals && quote.optionals.length > 0)
					{
						a.href = OTABO_BOOKING_OPTIONALS_URL + '&qid=' + quote.id;
					}
					else
					{
						a.href = OTABO_BOOKING_URL + '&qid=' + quote.id;
					}
					
					var button = document.createElement('button');
					button.innerHTML = _S.results_select;
					a.appendChild(button);
					
					div.appendChild(a);
				}
			}
			
			printResults(response.result.quotes);
		}
		else
		{
			document.getElementById('otabo_error').style.display = 'block';
			document.getElementById('otabo_error_msg').innerHTML = response && response.error ? response.error : response;
		}

		loading.style.display = 'none';
	});
}
